@@ -2,6 +2,7 @@ import json
 import os
 import shutil
 import subprocess
+import tempfile
 
 import hvac
 import requests
@@ -55,6 +56,13 @@ class RundeckJobs(object):
     def run_command(self, command, cwd, check=True):
         subprocess.run(command, cwd=cwd, check=check)
 
+    def clone_rundeck_codebase(self, gitlab_deploy_token: str):
+        repository_directory = tempfile.mkdtemp()
+        self.run_command(["git", "clone", "--depth", "1",
+                          f"https://oauth2:{gitlab_deploy_token}@gitlab.zadapps.info/infrastructure/rundeck/rundeck.git",
+                          repository_directory], cwd="/tmp")
+        return repository_directory
+
     def search_uptimerobot(
             self,
             deployment_action: str = os.environ.get(
@@ -389,14 +397,22 @@ class RundeckJobs(object):
                 'RD_OPTION_VAULT_LOGIN_USERNAME'),
             vault_login_password: str = os.environ.get(
                 'RD_OPTION_VAULT_LOGIN_PASSWORD'),
-            terraform_code_dir: str = f"{os.path.expanduser('~')}/codebase/terraform/rootmodule/nextjs_build",
     ):
         pg_backend_conn_str = f"postgres://{pg_user}:{pg_password}@{pg_ip}:{pg_port}/{pg_db}"
 
         config_dir_location = f'/tmp/{fqdn}.{deployment_environment}.build'
         rmdir(config_dir_location)
-        # if os.path.exists(f"{terraform_code_dir}/.terraform.lock.hcl"):
-        #     os.remove(f"{terraform_code_dir}/.terraform.lock.hcl")
+        vault_client = hvac.Client(
+            url='https://vault.zadapps.info',
+        )
+        vault_client.login(
+            "/v1/auth/{0}/login/{1}".format("userpass", vault_login_username),
+            json={"password": vault_login_password},
+        )
+        gitlab_deploy_token = vault_client.secrets.kv.read_secret_version(
+            path=f'tenant/devops/zadgroup/gitlab-deploy-token')['data']['data']['token']
+        rundeck_codebase_dir = self.clone_rundeck_codebase(gitlab_deploy_token)
+        terraform_code_dir = f"{rundeck_codebase_dir}/terraform/rootmodule/nextjs_build"
 
         backend_config_file_location = f"/tmp/{fqdn}.{deployment_environment}.build.backend.tfvars"
         backend_config_file_content = f'''conn_str = "{pg_backend_conn_str}"'''
@@ -421,15 +437,18 @@ class RundeckJobs(object):
         write_into_file(vars_file_content, vars_file_location)
 
         prepare_terraform_environment(config_dir_location)
-        self.run_command(["terraform", "init", "-input=false", "-reconfigure", "-force-copy",
-                          f"-backend-config", backend_config_file_location],
-                         cwd=terraform_code_dir, check=True)
         try:
             subprocess.run(["terraform", "workspace", "select", f"{fqdn}.build"],
                            cwd=terraform_code_dir, check=True)
+            self.run_command(["terraform", "init", "-input=false", "-reconfigure", "-force-copy",
+                              f"-backend-config", backend_config_file_location],
+                             cwd=terraform_code_dir, check=True)
         except subprocess.CalledProcessError:
             subprocess.run(["terraform", "workspace", "new", f"{fqdn}.build"],
                            cwd=terraform_code_dir, check=True)
+            self.run_command(["terraform", "init", "-input=false", "-reconfigure", "-force-copy",
+                              f"-backend-config", backend_config_file_location],
+                             cwd=terraform_code_dir, check=True)
 
         plan_file_location = f"{config_dir_location}/config.plan"
 
@@ -449,6 +468,7 @@ class RundeckJobs(object):
                               "default"], cwd=terraform_code_dir, check=True)
             self.run_command(["terraform", "workspace", "delete", f"{fqdn}.build"],
                              cwd=terraform_code_dir, check=True)
+        rmdir(terraform_code_dir)
 
     @retry(wait=wait_random(*wait_random_range), stop=stop_after_attempt(number_of_retries))
     def nextjs_deploy(
@@ -469,7 +489,6 @@ class RundeckJobs(object):
             jira_issue_key: str = os.environ.get("RD_OPTION_JIRA_ISSUE_KEY"),
             terraform_cloud_token: str = os.environ.get(
                 "RD_OPTION_TERRAFORM_CLOUD_TOKEN"),
-            terraform_code_dir: str = f"{os.path.expanduser('~')}/codebase/terraform/rootmodule/nextjs_deploy"
     ):
 
         fqdn_parts = extract_domain_parts(fqdn)
@@ -485,8 +504,10 @@ class RundeckJobs(object):
 
         config_dir_location = f'/tmp/{fqdn}'
         rmdir(config_dir_location)
-        # if os.path.exists(f"{terraform_code_dir}/.terraform.lock.hcl"):
-        #     os.remove(f"{terraform_code_dir}/.terraform.lock.hcl")
+        gitlab_deploy_token = vault_client.secrets.kv.read_secret_version(
+            path=f'tenant/devops/zadgroup/gitlab-deploy-token')['data']['data']['token']
+        rundeck_codebase_dir = self.clone_rundeck_codebase(gitlab_deploy_token)
+        terraform_code_dir = f"{rundeck_codebase_dir}/terraform/rootmodule/nextjs_deploy"
 
         backend_config_file_location = f"/tmp/{fqdn}.backend.tfvars"
         backend_config_file_content = '''
@@ -547,3 +568,5 @@ class RundeckJobs(object):
                                                'RD_OPTION_WITH_VCS_REPO'),
                                            execution_mode=execution_mode, deployment_environment=deployment_environment,
                                            deployment_action=deployment_action)
+
+        rmdir(terraform_code_dir)
